window.Gleam.initSearch([{"doc":"json_canvas","title":"json_canvas","content":"# json_canvas\n\n[![Package Version](https://img.shields.io/hexpm/v/json_canvas)](https://hex.pm/packages/json_canvas)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/json_canvas/)\n\nJSON Canvas library for Gleam\n\n## Installation\n\n```sh\ngleam add json_canvas\n```\n\n## Usage\n\n```gleam\nimport gleam/int\nimport gleam/io\nimport gleam/list\nimport json_canvas\nimport simplifile\n\npub fn main() {\n  let assert Ok(content) = simplifile.read(&quot;input.canvas&quot;)\n  let assert Ok(canvas) = json_canvas.decode(content)\n\n  let nodes = canvas.nodes\n  let edges = canvas.edges\n\n  io.println(&quot;Nodes count: &quot; &lt;&gt; int.to_string(list.length(nodes)))\n  io.println(&quot;Edges count: &quot; &lt;&gt; int.to_string(list.length(edges)))\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/json_canvas&gt;.\n\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"json_canvas/types","title":"Canvas","content":"pub type Canvas {\n  Canvas(nodes: List(Node), edges: List(Edge))\n}\n\nCanvas(nodes: List(Node), edges: List(Edge))\n\n\nSynonyms:\njson_canvas/types.Canvas\njson_canvas/types Canvas","url":"json_canvas/types.html#Canvas"},{"doc":"json_canvas/types","title":"Color","content":"pub type Color {\n  Color(String)\n}\n\nColor(String)\n\n\nSynonyms:\njson_canvas/types.Color\njson_canvas/types Color","url":"json_canvas/types.html#Color"},{"doc":"json_canvas/types","title":"Edge","content":"pub type Edge {\n  Edge(\n    id: EdgeId,\n    from_node: NodeId,\n    from_side: Option(Side),\n    from_end: EndpointShape,\n    to_node: NodeId,\n    to_side: Option(Side),\n    to_end: EndpointShape,\n    color: Option(Color),\n    label: Option(EdgeLabel),\n  )\n}\n\nEdge(\n  id: EdgeId,\n  from_node: NodeId,\n  from_side: Option(Side),\n  from_end: EndpointShape,\n  to_node: NodeId,\n  to_side: Option(Side),\n  to_end: EndpointShape,\n  color: Option(Color),\n  label: Option(EdgeLabel),\n)\n\n\nSynonyms:\njson_canvas/types.Edge\njson_canvas/types Edge","url":"json_canvas/types.html#Edge"},{"doc":"json_canvas/types","title":"EdgeId","content":"pub type EdgeId {\n  EdgeId(String)\n}\n\nEdgeId(String)\n\n\nSynonyms:\njson_canvas/types.EdgeId\njson_canvas/types EdgeId","url":"json_canvas/types.html#EdgeId"},{"doc":"json_canvas/types","title":"EdgeLabel","content":"pub type EdgeLabel {\n  EdgeLabel(String)\n}\n\nEdgeLabel(String)\n\n\nSynonyms:\njson_canvas/types.EdgeLabel\njson_canvas/types EdgeLabel","url":"json_canvas/types.html#EdgeLabel"},{"doc":"json_canvas/types","title":"EndpointShape","content":"pub type EndpointShape {\n  WithArrow\n  WithoutArrow\n}\n\nWithArrow\n\n\nWithoutArrow\n\n\nSynonyms:\njson_canvas/types.EndpointShape\njson_canvas/types EndpointShape","url":"json_canvas/types.html#EndpointShape"},{"doc":"json_canvas/types","title":"FilePath","content":"pub type FilePath {\n  FilePath(String)\n}\n\nFilePath(String)\n\n\nSynonyms:\njson_canvas/types.FilePath\njson_canvas/types FilePath","url":"json_canvas/types.html#FilePath"},{"doc":"json_canvas/types","title":"GroupBackground","content":"pub type GroupBackground {\n  GroupBackground(String)\n}\n\nGroupBackground(String)\n\n\nSynonyms:\njson_canvas/types.GroupBackground\njson_canvas/types GroupBackground","url":"json_canvas/types.html#GroupBackground"},{"doc":"json_canvas/types","title":"GroupBackgroundStyle","content":"pub type GroupBackgroundStyle {\n  Cover\n  Ratio\n  Repeat\n}\n\nCover\n\n\nRatio\n\n\nRepeat\n\n\nSynonyms:\njson_canvas/types.GroupBackgroundStyle\njson_canvas/types GroupBackgroundStyle","url":"json_canvas/types.html#GroupBackgroundStyle"},{"doc":"json_canvas/types","title":"GroupLabel","content":"pub type GroupLabel {\n  GroupLabel(String)\n}\n\nGroupLabel(String)\n\n\nSynonyms:\njson_canvas/types.GroupLabel\njson_canvas/types GroupLabel","url":"json_canvas/types.html#GroupLabel"},{"doc":"json_canvas/types","title":"Node","content":"pub type Node {\n  TextNode(\n    id: NodeId,\n    x: Int,\n    y: Int,\n    width: Int,\n    height: Int,\n    color: Option(Color),\n    text: String,\n  )\n  FileNode(\n    id: NodeId,\n    x: Int,\n    y: Int,\n    width: Int,\n    height: Int,\n    color: Option(Color),\n    path: FilePath,\n    subpath: Option(Subpath),\n  )\n  LinkNode(\n    id: NodeId,\n    x: Int,\n    y: Int,\n    width: Int,\n    height: Int,\n    color: Option(Color),\n    url: Url,\n  )\n  GroupNode(\n    id: NodeId,\n    x: Int,\n    y: Int,\n    width: Int,\n    height: Int,\n    color: Option(Color),\n    label: Option(GroupLabel),\n    background: Option(GroupBackground),\n    background_style: Option(GroupBackgroundStyle),\n  )\n}\n\nTextNode(\n  id: NodeId,\n  x: Int,\n  y: Int,\n  width: Int,\n  height: Int,\n  color: Option(Color),\n  text: String,\n)\n\n\nFileNode(\n  id: NodeId,\n  x: Int,\n  y: Int,\n  width: Int,\n  height: Int,\n  color: Option(Color),\n  path: FilePath,\n  subpath: Option(Subpath),\n)\n\n\nLinkNode(\n  id: NodeId,\n  x: Int,\n  y: Int,\n  width: Int,\n  height: Int,\n  color: Option(Color),\n  url: Url,\n)\n\n\nGroupNode(\n  id: NodeId,\n  x: Int,\n  y: Int,\n  width: Int,\n  height: Int,\n  color: Option(Color),\n  label: Option(GroupLabel),\n  background: Option(GroupBackground),\n  background_style: Option(GroupBackgroundStyle),\n)\n\n\nSynonyms:\njson_canvas/types.Node\njson_canvas/types Node","url":"json_canvas/types.html#Node"},{"doc":"json_canvas/types","title":"NodeId","content":"pub type NodeId {\n  NodeId(String)\n}\n\nNodeId(String)\n\n\nSynonyms:\njson_canvas/types.NodeId\njson_canvas/types NodeId","url":"json_canvas/types.html#NodeId"},{"doc":"json_canvas/types","title":"Side","content":"pub type Side {\n  Top\n  Right\n  Bottom\n  Left\n}\n\nTop\n\n\nRight\n\n\nBottom\n\n\nLeft\n\n\nSynonyms:\njson_canvas/types.Side\njson_canvas/types Side","url":"json_canvas/types.html#Side"},{"doc":"json_canvas/types","title":"Subpath","content":"pub type Subpath {\n  Subpath(String)\n}\n\nSubpath(String)\n\n\nSynonyms:\njson_canvas/types.Subpath\njson_canvas/types Subpath","url":"json_canvas/types.html#Subpath"},{"doc":"json_canvas/types","title":"Url","content":"pub type Url {\n  Url(String)\n}\n\nUrl(String)\n\n\nSynonyms:\njson_canvas/types.Url\njson_canvas/types Url","url":"json_canvas/types.html#Url"},{"doc":"json_canvas/types","title":"json_canvas/types","content":"","url":"json_canvas/types.html"},{"doc":"json_canvas/decode/edge","title":"decode_edge","content":"pub fn decode_edge(\n  dyn: Dynamic,\n) -&gt; Result(Edge, List(DecodeError))\n\nSynonyms:\njson_canvas/decode/edge.decode_edge\njson_canvas/decode/edge decode_edge","url":"json_canvas/decode/edge.html#decode_edge"},{"doc":"json_canvas/decode/edge","title":"decode_endpoint_shape","content":"pub fn decode_endpoint_shape(\n  dyn: Dynamic,\n) -&gt; Result(EndpointShape, List(DecodeError))\n\nSynonyms:\njson_canvas/decode/edge.decode_endpoint_shape\njson_canvas/decode/edge decode_endpoint_shape","url":"json_canvas/decode/edge.html#decode_endpoint_shape"},{"doc":"json_canvas/decode/edge","title":"decode_side","content":"pub fn decode_side(\n  dyn: Dynamic,\n) -&gt; Result(Side, List(DecodeError))\n\nSynonyms:\njson_canvas/decode/edge.decode_side\njson_canvas/decode/edge decode_side","url":"json_canvas/decode/edge.html#decode_side"},{"doc":"json_canvas/decode/edge","title":"json_canvas/decode/edge","content":"","url":"json_canvas/decode/edge.html"},{"doc":"json_canvas/decode/node","title":"decode_group_background_style","content":"pub fn decode_group_background_style(\n  dyn: Dynamic,\n) -&gt; Result(GroupBackgroundStyle, List(DecodeError))\n\nSynonyms:\njson_canvas/decode/node.decode_group_background_style\njson_canvas/decode/node decode_group_background_style","url":"json_canvas/decode/node.html#decode_group_background_style"},{"doc":"json_canvas/decode/node","title":"decode_node","content":"pub fn decode_node(\n  dyn: Dynamic,\n) -&gt; Result(Node, List(DecodeError))\n\nSynonyms:\njson_canvas/decode/node.decode_node\njson_canvas/decode/node decode_node","url":"json_canvas/decode/node.html#decode_node"},{"doc":"json_canvas/decode/node","title":"json_canvas/decode/node","content":"","url":"json_canvas/decode/node.html"},{"doc":"json_canvas/decode/canvas","title":"decode_canvas","content":"pub fn decode_canvas(\n  dyn: Dynamic,\n) -&gt; Result(Canvas, List(DecodeError))\n\nSynonyms:\njson_canvas/decode/canvas.decode_canvas\njson_canvas/decode/canvas decode_canvas","url":"json_canvas/decode/canvas.html#decode_canvas"},{"doc":"json_canvas/decode/canvas","title":"json_canvas/decode/canvas","content":"","url":"json_canvas/decode/canvas.html"},{"doc":"json_canvas","title":"decode","content":"pub fn decode(\n  from json_canvas: String,\n) -&gt; Result(Canvas, DecodeError)\n Decode a JSON Canvas string representation into a `Canvas` type.\nSynonyms:\njson_canvas.decode\njson_canvas decode","url":"json_canvas.html#decode"},{"doc":"json_canvas","title":"json_canvas","content":"","url":"json_canvas.html"}]);